"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Compose = exports.ComposeMany = void 0;
const composition_1 = require("../entities/composition");
function checkAndInitializeCompositions(target) {
    if (!target.hasOwnProperty('compositions')) {
        Object.defineProperty(target, 'compositions', {
            value: new Array()
        });
    }
}
/**
 * Specify on the array properties.
 *
 * Typescript compiles to Javascript before execution. Since Javascript doesn't feature types,
 * the type information of an array is lost at runtime, hence making it impossible to parse an
 * array of objects to proper types.
 * @param type Type parameter that denotes the class to which an array of object needs to be casted to.
 */
function ComposeMany(type) {
    return (target, propertyKey) => {
        checkAndInitializeCompositions(target);
        target.compositions.push(new composition_1.Composition(propertyKey, type, true));
    };
}
exports.ComposeMany = ComposeMany;
/**
 * Specify on the object properties.
 *
 * Typescript compiles to Javascript before execution. Since Javascript doesn't feature types,
 * the type information is lost at runtime, hence making it impossible to parse an
 * objects to proper types.
 * @param type Type parameter that denotes the class to which an object needs to be casted to.
 */
function Compose(type) {
    return (target, propertyKey) => {
        checkAndInitializeCompositions(target);
        target.compositions.push(new composition_1.Composition(propertyKey, type, false));
    };
}
exports.Compose = Compose;
