import { Model } from "../models/baseModel";
/**
 * Specifies that a controller method is to be exposed as an HTTP GET endpoint.
 * @param route Optional route for the method to be exposed as endpoint.
 * If not provided, assumes the default for this resource.
 */
export declare function Get(route?: string): (target: any, propertyKey: string) => void;
/**
 * Specifies that a controller method is to be exposed as an HTTP POST endpoint.
 * @param route Optional route for the method to be exposed as endpoint.
 * If not provided, assumes the default for this resource.
 */
export declare function Post(route?: string): (target: any, propertyKey: string) => void;
/**
 * Specifies that a controller method is to be exposed as an HTTP PUT endpoint.
 * @param route Optional route for the method to be exposed as endpoint.
 * If not provided, assumes the default for this resource.
 */
export declare function Put(route?: string): (target: any, propertyKey: string) => void;
/**
 * Specifies that a controller method is to be exposed as an HTTP PATCH endpoint.
 * @param route Optional route for the method to be exposed as endpoint.
 * If not provided, assumes the default for this resource.
 */
export declare function Patch(route?: string): (target: any, propertyKey: string) => void;
/**
 * Specifies that a controller method is to be exposed as an HTTP DELETE endpoint.
 * @param route Optional route for the method to be exposed as endpoint.
 * If not provided, assumes the default for this resource.
 */
export declare function Delete(route?: string): (target: any, propertyKey: string) => void;
/**
 * When set on a route parameter, specifies that the parameter comes from the query of the request.
 */
export declare function FromQuery(model: typeof Model): (target: any, functionKey: string, parameterIndex: number) => void;
/**
 * When set on a route parameter, specifies that the parameter comes from the body of the request.
 */
export declare function FromBody(model: typeof Model): (target: any, functionKey: string, parameterIndex: number) => void;
/**
 * When set on a route parameter, specifies that the parameter comes from the route of the request.
 * @param parameterName Parameter name to be used. Note that the parameter name specified here should match with the one in the route.
 */
export declare function FromRoute(parameterName: string): (target: any, functionKey: string, parameterIndex: number) => void;
